==> u_team_core-fabric-1.19.4-5.0.2.361-sources.jar: info/u_team/u_team_core/gui/elements/USlider.java <==
package info.u_team.u_team_core.gui.elements;

import info.u_team.u_team_core.api.gui.BackgroundColorProvider;
import info.u_team.u_team_core.api.gui.Scalable;
import info.u_team.u_team_core.api.gui.ScaleProvider;
import info.u_team.u_team_core.api.gui.TextProvider;
import info.u_team.u_team_core.api.gui.TextureProvider;
import info.u_team.u_team_core.api.gui.WidgetRenderable;
import info.u_team.u_team_core.util.RGBA;
import info.u_team.u_team_core.util.RenderUtil;
import info.u_team.u_team_core.util.WidgetUtil;
import net.minecraft.class_2561;
import net.minecraft.class_4587;

public non-sealed class USlider extends AbstractSliderLogic implements WidgetRenderable, BackgroundColorProvider, TextProvider, Scalable, ScaleProvider {
	
	protected static final OnSliderChange EMPTY_SLIDER = AbstractSliderLogic.EMPTY_SLIDER;
	
	protected static final RGBA WHITE = UButton.WHITE;
	protected static final RGBA LIGHT_GRAY = UButton.LIGHT_GRAY;
	
	protected TextureProvider sliderBackgroundTextureProvider;
	protected RGBA sliderBackgroundColor;
	
	protected TextureProvider sliderTextureProvider;
	protected RGBA sliderColor;
	
	protected RGBA textColor;
	protected RGBA disabledTextColor;
	
	protected float scale = 1;
	
	public USlider(int x, int y, int width, int height, class_2561 prefix, class_2561 suffix, double minValue, double maxValue, double value, boolean decimalPrecision, boolean drawDescription) {
		this(x, y, width, height, prefix, suffix, minValue, maxValue, value, decimalPrecision, drawDescription, EMPTY_SLIDER);
	}
	
	public USlider(int x, int y, int width, int height, class_2561 prefix, class_2561 suffix, double minValue, double maxValue, double value, boolean decimalPrecision, boolean drawDescription, OnSliderChange slider) {
		super(x, y, width, height, prefix, suffix, minValue, maxValue, value, decimalPrecision, drawDescription, slider);
		sliderBackgroundTextureProvider = new WidgetTextureProvider(field_41787, this::method_25356);
		sliderBackgroundColor = WHITE;
		sliderTextureProvider = new WidgetTextureProvider(field_41787, this::method_48204);
		sliderColor = WHITE;
		textColor = WHITE;
		disabledTextColor = LIGHT_GRAY;
	}
	
	public RGBA getSliderBackgroundColor() {
		return sliderBackgroundColor;
	}
	
	public void setSliderBackgroundColor(RGBA sliderBackgroundColor) {
		this.sliderBackgroundColor = sliderBackgroundColor;
	}
	
	public RGBA getSliderColor() {
		return sliderColor;
	}
	
	public void setSliderColor(RGBA sliderColor) {
		this.sliderColor = sliderColor;
	}
	
	public RGBA getTextColor() {
		return textColor;
	}
	
	public void setTextColor(RGBA textColor) {
		this.textColor = textColor;
	}
	
	public RGBA getDisabledTextColor() {
		return disabledTextColor;
	}
	
	public void setDisabledTextColor(RGBA disabledTextColor) {
		this.disabledTextColor = disabledTextColor;
	}
	
	@Override
	public float getScale() {
		return scale;
	}
	
	@Override
	public void setScale(float scale) {
		this.scale = scale;
	}
	
	@Override
	public void method_48579(class_4587 poseStack, int mouseX, int mouseY, float partialTick) {
		WidgetUtil.renderWidget(this, poseStack, mouseX, mouseY, partialTick);
	}
	
	@Override
	public void renderWidgetTexture(class_4587 poseStack, int mouseX, int mouseY, float partialTick) {
		WidgetUtil.renderButtonLikeTexture(this, sliderBackgroundTextureProvider, poseStack, mouseX, mouseY, partialTick);
	}
	
	@Override
	public void renderBackground(class_4587 poseStack, int mouseX, int mouseY, float partialTick) {
		final RGBA color = WidgetUtil.respectWidgetAlpha(this, getCurrentSliderColor(poseStack, mouseX, mouseY, partialTick));
		RenderUtil.drawContinuousTexturedBox(poseStack, field_22760 + (int) (field_22753 * (field_22758 - 8)), field_22761, sliderTextureProvider.getU(), sliderTextureProvider.getV(), 8, field_22759, sliderTextureProvider.getWidth(), sliderTextureProvider.getHeight(), 2, 3, 2, 2, 0, sliderTextureProvider.getTexture(), color);
	}
	
	@Override
	public void renderForeground(class_4587 poseStack, int mouseX, int mouseY, float partialTick) {
		WidgetUtil.renderText(this, poseStack, mouseX, mouseY, partialTick);
	}
	
	@Override
	public RGBA getCurrentBackgroundColor(class_4587 poseStack, int mouseX, int mouseY, float partialTick) {
		return sliderBackgroundColor;
	}
	
	public RGBA getCurrentSliderColor(class_4587 poseStack, int mouseX, int mouseY, float partialTick) {
		return sliderColor;
	}
	
	@Override
	public class_2561 getCurrentText() {
		return method_25369();
	}
	
	@Override
	public RGBA getCurrentTextColor(class_4587 poseStack, int mouseX, int mouseY, float partialTick) {
		return field_22763 ? textColor : disabledTextColor;
	}
	
	@Override
	public float getCurrentScale(class_4587 poseStack, int mouseX, int mouseY, float partialTick) {
		return scale;
	}
}

==> u_team_core-fabric-1.20.1-5.1.4.382-sources.jar: info/u_team/u_team_core/gui/elements/USlider.java <==
package info.u_team.u_team_core.gui.elements;

import info.u_team.u_team_core.api.gui.BackgroundColorProvider;
import info.u_team.u_team_core.api.gui.Scalable;
import info.u_team.u_team_core.api.gui.ScaleProvider;
import info.u_team.u_team_core.api.gui.TextProvider;
import info.u_team.u_team_core.api.gui.TextureProvider;
import info.u_team.u_team_core.api.gui.WidgetRenderable;
import info.u_team.u_team_core.util.RGBA;
import info.u_team.u_team_core.util.RenderUtil;
import info.u_team.u_team_core.util.WidgetUtil;
import net.minecraft.class_2561;
import net.minecraft.class_332;

public non-sealed class USlider extends AbstractSliderLogic implements WidgetRenderable, BackgroundColorProvider, TextProvider, Scalable, ScaleProvider {
	
	protected static final OnSliderChange EMPTY_SLIDER = AbstractSliderLogic.EMPTY_SLIDER;
	
	protected static final RGBA WHITE = UButton.WHITE;
	protected static final RGBA LIGHT_GRAY = UButton.LIGHT_GRAY;
	
	protected TextureProvider sliderBackgroundTextureProvider;
	protected RGBA sliderBackgroundColor;
	
	protected TextureProvider sliderTextureProvider;
	protected RGBA sliderColor;
	
	protected RGBA textColor;
	protected RGBA disabledTextColor;
	
	protected float scale = 1;
	
	public USlider(int x, int y, int width, int height, class_2561 prefix, class_2561 suffix, double minValue, double maxValue, double value, boolean decimalPrecision, boolean drawDescription) {
		this(x, y, width, height, prefix, suffix, minValue, maxValue, value, decimalPrecision, drawDescription, EMPTY_SLIDER);
	}
	
	public USlider(int x, int y, int width, int height, class_2561 prefix, class_2561 suffix, double minValue, double maxValue, double value, boolean decimalPrecision, boolean drawDescription, OnSliderChange slider) {
		super(x, y, width, height, prefix, suffix, minValue, maxValue, value, decimalPrecision, drawDescription, slider);
		sliderBackgroundTextureProvider = new WidgetTextureProvider(field_41787, this::method_25356);
		sliderBackgroundColor = WHITE;
		sliderTextureProvider = new WidgetTextureProvider(field_41787, this::method_48204);
		sliderColor = WHITE;
		textColor = WHITE;
		disabledTextColor = LIGHT_GRAY;
	}
	
	public RGBA getSliderBackgroundColor() {
		return sliderBackgroundColor;
	}
	
	public void setSliderBackgroundColor(RGBA sliderBackgroundColor) {
		this.sliderBackgroundColor = sliderBackgroundColor;
	}
	
	public RGBA getSliderColor() {
		return sliderColor;
	}
	
	public void setSliderColor(RGBA sliderColor) {
		this.sliderColor = sliderColor;
	}
	
	public RGBA getTextColor() {
		return textColor;
	}
	
	public void setTextColor(RGBA textColor) {
		this.textColor = textColor;
	}
	
	public RGBA getDisabledTextColor() {
		return disabledTextColor;
	}
	
	public void setDisabledTextColor(RGBA disabledTextColor) {
		this.disabledTextColor = disabledTextColor;
	}
	
	@Override
	public float getScale() {
		return scale;
	}
	
	@Override
	public void setScale(float scale) {
		this.scale = scale;
	}
	
	@Override
	public void method_48579(class_332 guiGraphics, int mouseX, int mouseY, float partialTick) {
		WidgetUtil.renderWidget(this, guiGraphics, mouseX, mouseY, partialTick);
	}
	
	@Override
	public void renderWidgetTexture(class_332 guiGraphics, int mouseX, int mouseY, float partialTick) {
		WidgetUtil.renderButtonLikeTexture(this, sliderBackgroundTextureProvider, guiGraphics, mouseX, mouseY, partialTick);
	}
	
	@Override
	public void renderBackground(class_332 guiGraphics, int mouseX, int mouseY, float partialTick) {
		final RGBA color = WidgetUtil.respectWidgetAlpha(this, getCurrentSliderColor(guiGraphics, mouseX, mouseY, partialTick));
		RenderUtil.drawContinuousTexturedBox(guiGraphics.method_51448(), field_22760 + (int) (field_22753 * (field_22758 - 8)), field_22761, sliderTextureProvider.getU(), sliderTextureProvider.getV(), 8, field_22759, sliderTextureProvider.getWidth(), sliderTextureProvider.getHeight(), 2, 3, 2, 2, 0, sliderTextureProvider.getTexture(), color);
	}
	
	@Override
	public void renderForeground(class_332 guiGraphics, int mouseX, int mouseY, float partialTick) {
		WidgetUtil.renderText(this, guiGraphics, mouseX, mouseY, partialTick);
	}
	
	@Override
	public RGBA getCurrentBackgroundColor(class_332 guiGraphics, int mouseX, int mouseY, float partialTick) {
		return sliderBackgroundColor;
	}
	
	public RGBA getCurrentSliderColor(class_332 guiGraphics, int mouseX, int mouseY, float partialTick) {
		return sliderColor;
	}
	
	@Override
	public class_2561 getCurrentText() {
		return method_25369();
	}
	
	@Override
	public RGBA getCurrentTextColor(class_332 guiGraphics, int mouseX, int mouseY, float partialTick) {
		return field_22763 ? textColor : disabledTextColor;
	}
	
	@Override
	public float getCurrentScale(class_332 guiGraphics, int mouseX, int mouseY, float partialTick) {
		return scale;
	}
}
